@@ -1,8 +1,8 @@
 /*
  * filter_param.c
- * $Id: filter_param.c,v 1.20.4.2 2004/01/11 00:14:22 richi Exp $
+ * $Id: filter_param.c,v 1.20.4.4 2004/10/23 13:14:19 richi Exp $
  *
- * Copyright (C) 2000 Richard Guenther
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Richard Guenther
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -117,8 +117,9 @@ static void paramdb_op_delete(gldb_item_t *item)
 		fbuf_unref(p->u.buf);
 
 	/* Notify the associated filter of the change. */
-	glsig_emit(&p->emitter, GLSIG_FILTER_CHANGED,
-		   ((filter_paramdb_t *)p->entry.db)->node);
+	if (p->entry.db)
+		glsig_emit(&p->emitter, GLSIG_FILTER_CHANGED,
+			   ((filter_paramdb_t *)p->entry.db)->node);
 	glsig_delete_all(&p->emitter);
 }
 
