@@ -1,7 +1,7 @@
 /*
  * gpsm.c
  *
- * Copyright (C) 2001 Richard Guenther
+ * Copyright (C) 2001, 2002, 2003, 2004 Richard Guenther
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,6 +62,9 @@ struct glame_list_head oplist;
 static long op_max_listsize = 5;
 static int op_listsize;
 
+/* Wether we do overlapping checks on placement.  */
+static int gpsm_placement_checks = 1;
+
 
 /* Forwards. */
 static gpsm_item_t *gpsm_newitem(int type);
@@ -501,7 +504,9 @@ empty:
 	lost->item.vposition = 0;
 	lost->item.hsize = 0;
 	lost->item.vsize = 0;
+	gpsm_placement_checks = 0;
 	insert_childs(root, xmlDocGetRootElement(doc), lost);
+	gpsm_placement_checks = 1;
 	if (gpsm_item_vsize(lost) != 0)
 		gpsm_item_place(root, (gpsm_item_t *)lost,
 				0, gpsm_item_vsize(root) + 1);
@@ -1016,7 +1021,7 @@ int gpsm_item_can_place(gpsm_grp_t *grp, gpsm_item_t *item,
 	gpsm_grp_foreach_item(grp, it) {
 		if (it == item)
 			continue;
-		if (ITEMS_DO_OVERLAP(it, &dummy))
+		if (gpsm_placement_checks && ITEMS_DO_OVERLAP(it, &dummy))
 			return 0;
 	}
 
@@ -1101,7 +1106,7 @@ int gpsm_hbox_can_insert(gpsm_grp_t *grp, gpsm_item_t *item,
 	gpsm_grp_foreach_item(grp, it) {
 		if (item == it)
 			continue;
-		if (X0(it) < hpos && hpos <= X1(it))
+		if (gpsm_placement_checks && X0(it) < hpos && hpos <= X1(it))
 			return 0;
 	}
 
@@ -1125,7 +1130,7 @@ int gpsm_vbox_can_insert(gpsm_grp_t *grp, gpsm_item_t *item,
 	gpsm_grp_foreach_item(grp, it) {
 		if (item == it)
 			continue;
-		if (Y0(it) < vpos && vpos <= Y1(it))
+		if (gpsm_placement_checks && Y0(it) < vpos && vpos <= Y1(it))
 			return 0;
 	}
 
