@@ -1,7 +1,7 @@
 /*
- * $Id: gtkswapfilebuffer.c,v 1.15 2002/05/29 22:23:48 richi Exp $
+ * $Id: gtkswapfilebuffer.c,v 1.15.4.2 2004/10/23 13:14:21 richi Exp $
  *
- * Copyright (c) 2000 Richard Guenther
+ * Copyright (c) 2000, 2001, 2002, 2004 Richard Guenther
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -186,6 +186,7 @@ gtk_swapfile_buffer_get_samples (GtkWaveBuffer *wavebuffer,
 	SAMPLE **trackm, **s;
 	struct sw_stat *trackst;
 	off_t *trackpos;
+	gint16 *data16 = data;
 
 	/* Init. */
 	trackm = (SAMPLE **)alloca(swapfile->nrtracks*sizeof(SAMPLE *));
@@ -230,9 +231,9 @@ gtk_swapfile_buffer_get_samples (GtkWaveBuffer *wavebuffer,
 		while (cnt--) {
 			for (i=0; i<swapfile->nrtracks; i++) {
 				if (!trackm[i] || !(channel_mask & (1<<i)))
-					*((gint16 *)data)++ = 0;
+					*(data16++) = 0;
 				else
-					*((gint16 *)data)++ = SAMPLE2SHORT(*s[i]++);
+					*(data16++) = SAMPLE2SHORT(*s[i]++);
 			}
 		}
 
