@@ -1,9 +1,10 @@
 /*
  * main.c
  *
- * $Id: main.c,v 1.114.2.3 2003/12/31 22:13:30 richi Exp $
+ * $Id: main.c,v 1.114.2.5 2004/10/23 13:14:20 richi Exp $
  *
- * Copyright (C) 2001 Johannes Hirche, Richard Guenther
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Johannes Hirche,
+ * 	Richard Guenther
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,10 +28,10 @@
 
 #include <stdlib.h>
 #include <unistd.h>
+#include <gnome.h>
 #ifdef HAVE_LIBGLADE
 #include <glade/glade.h>
 #endif
-#include <libintl.h>
 #include "swapfile.h"
 #include "glmid.h"
 #include "swapfilegui.h"
