@@ -1,9 +1,10 @@
 /*
  * swapfilegui.c
  *
- * $Id: swapfilegui.c,v 1.88.2.2 2003/04/12 12:08:38 richi Exp $
+ * $Id: swapfilegui.c,v 1.88.2.4 2004/10/23 13:14:20 richi Exp $
  * 
- * Copyright (C) 2001 Richard Guenther, Johannes Hirche, Alexander Ehlert
+ * Copyright (C) 2001, 2002, 2003, 2004 Richard Guenther, Johannes Hirche,
+ * 	Alexander Ehlert
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +26,6 @@
 #include <config.h>
 #endif
 
-#include <libintl.h>
 #include <stdio.h>
 #include <errno.h>
 #include <gnome.h>
