@@ -1,8 +1,8 @@
 /*
  * basic_sample.c
- * $Id: basic_sample.c,v 1.65.4.1 2003/04/19 18:23:20 richi Exp $
+ * $Id: basic_sample.c,v 1.65.4.3 2004/10/23 13:14:23 richi Exp $
  *
- * Copyright (C) 2000 Richard Guenther
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Richard Guenther
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -846,6 +846,8 @@ static int vadjust_set_param(filter_param_t *param, const void *val)
 	gain = *((double *)val);
 	
 	if (strcmp("factor", filterparam_label(param))==0) {
+		if (gain <= 0.0)
+			return -1;
 		anyscale = filterparamdb_get_param(filter_paramdb(n), "dbgain");
 		ngain = GAIN2DB(gain);
 		n->priv = param;
@@ -854,6 +856,8 @@ static int vadjust_set_param(filter_param_t *param, const void *val)
 	}
 	
 	if (strcmp("dbgain", filterparam_label(param))==0) {
+		if (gain < -200.0 || gain > 200.0)
+			return -1;
 		anyscale = filterparamdb_get_param(filter_paramdb(n), "factor");
 		ngain = DB2GAIN(gain);
 		n->priv = param;
