@@ -1,8 +1,8 @@
 /*
  * swapfile_io.c
- * $Id: swapfile_io.c,v 1.27.4.1 2003/04/13 18:51:03 richi Exp $
+ * $Id: swapfile_io.c,v 1.27.4.3 2004/10/23 13:14:24 richi Exp $
  *
- * Copyright (C) 2000 Richard Guenther
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Richard Guenther
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -272,11 +272,6 @@ static int swapfile_out_f(filter_t *n)
 
 	size = filterparam_val_long(
 		filterparamdb_get_param(filter_paramdb(n), "size"));
-	/* Limit size to current file size, if not -1 (which allows extension). */
-	if (size != -1) {
-		sw_fstat(fd, &st);
-		size = MIN(size, ((long)(st.size/SAMPLE_SIZE)) - offset);
-	}
 
 	pos_param = filterparamdb_get_param(
 		filter_paramdb(n), FILTERPARAM_LABEL_POS);
